************
Installation
************


Installing |popstar|
====================

The easiest way to install |popstar| is with PyPi.

.. code-block:: bash

    pip install popstar

To get the very latest version of the software, install it directly from GitHub.
    
.. code-block:: bash

    pip install git+https://github.com/dnidever/popstar

    

Dependencies
============

- numpy
- scipy
- astropy
- matplotlib
- dlnpyutils
- ferre
- gdown
